@@ -32,7 +32,7 @@ class TransactionsManager(Manager):
 
     __endpoint = '/transaction'
     def __init__(self, endpoint='/transaction'):
-        super().__init__(self)
+        super().__init__()
         self.__endpoint = endpoint
 
 
@@ -214,7 +214,7 @@ class CustomersManager(Manager):
     __endpoint = '/customer'
 
     def __init__(self):
-        super().__init__(self)
+        super().__init__()
 
     def create_customer(self, customer: Customer, meta=None):
         '''
@@ -404,7 +404,7 @@ class PlanManager(Manager):
     __endpoint = '/plan'
 
     def __init__(self, endpoint='/plan'):
-        super().__init__(self)
+        super().__init__()
         self.__endpoint = endpoint
 
     def create_plan(self, plan: Plan):
@@ -508,7 +508,7 @@ class TransfersManager(Manager):
 
     __endpoint = '/transfer'
     def __init__(self, endpoint='/transfer'):
-        super().__init__(self)
+        super().__init__()
         self.__endpoint = endpoint
 
 
